//! MATRIX

#![no_std]

pub mod matrix;

pub fn test(number: u8) -> u8 {
    number
}
